==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/sv/buddhist.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "detta kv.",
	"field-quarter-short-relative+1": "nästa kv.",
	"field-tue-relative+-1": "tisdag förra veckan",
	"field-year": "år",
	"field-wed-relative+0": "onsdag denna vecka",
	"field-wed-relative+1": "onsdag nästa vecka",
	"timeFormat-short": "HH.mm",
	"field-minute": "minut",
	"field-month-narrow-relative+-1": "förra mån.",
	"field-tue-narrow-relative+0": "denna tis.",
	"field-tue-narrow-relative+1": "nästa tis.",
	"field-thu-short-relative+0": "tors. denna vecka",
	"field-day-short-relative+-1": "i går",
	"field-thu-short-relative+1": "tors. nästa vecka",
	"field-day-relative+0": "i dag",
	"field-day-short-relative+-2": "i förrgår",
	"field-day-relative+1": "i morgon",
	"field-week-narrow-relative+0": "denna v.",
	"field-day-relative+2": "i övermorgon",
	"field-week-narrow-relative+1": "nästa v.",
	"field-wed-narrow-relative+-1": "förra ons.",
	"field-year-narrow": "år",
	"field-year-narrow-relative+0": "i år",
	"field-tue-relative+0": "tisdag denna vecka",
	"field-year-narrow-relative+1": "nästa år",
	"field-tue-relative+1": "tisdag nästa vecka",
	"field-second-short": "sek",
	"dayPeriods-format-narrow-am": "fm",
	"dateFormatItem-MMMd": "d MMM",
	"dayPeriods-format-abbr-am": "fm",
	"field-week-relative+0": "denna vecka",
	"field-month-relative+0": "denna månad",
	"field-week-relative+1": "nästa vecka",
	"field-month-relative+1": "nästa månad",
	"field-sun-narrow-relative+0": "denna sön.",
	"timeFormat-medium": "HH.mm.ss",
	"field-mon-short-relative+0": "mån. denna vecka",
	"field-sun-narrow-relative+1": "nästa sön.",
	"field-mon-short-relative+1": "mån. nästa vecka",
	"field-second-relative+0": "nu",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"dayPeriods-standAlone-abbr-pm": "e.m.",
	"field-month-short": "m",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-yyyyMd": "y-MM-dd G",
	"field-day": "dag",
	"field-year-relative+-1": "i fjol",
	"dayPeriods-format-wide-am": "fm",
	"field-sat-short-relative+-1": "lör. förra veckan",
	"field-hour-relative+0": "denna timme",
	"dateFormatItem-yyyyMEd": "E y-MM-dd G",
	"field-second-short-relative+0": "nu",
	"field-wed-relative+-1": "onsdag förra veckan",
	"field-sat-narrow-relative+-1": "förra lör.",
	"field-second": "sekund",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dayPeriods-standAlone-wide-pm": "eftermiddag",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-hour-short-relative+0": "denna timme",
	"field-quarter": "kvartal",
	"field-week-short": "v",
	"field-day-narrow-relative+0": "i dag",
	"field-day-narrow-relative+1": "i morgon",
	"field-day-narrow-relative+2": "i övermorgon",
	"quarters-standAlone-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"field-tue-short-relative+0": "tis. denna vecka",
	"field-tue-short-relative+1": "tis. nästa vecka",
	"field-month-short-relative+-1": "förra mån.",
	"field-mon-relative+-1": "måndag förra veckan",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "månad",
	"field-day-narrow": "dag",
	"field-minute-short": "min",
	"field-dayperiod": "fm/em",
	"field-sat-short-relative+0": "lör. denna vecka",
	"field-sat-short-relative+1": "lör. nästa vecka",
	"dayPeriods-format-narrow-pm": "em",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"BE"
	],
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"dayPeriods-format-abbr-pm": "em",
	"dateFormatItem-yyyyM": "y-MM G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "måndag denna vecka",
	"field-mon-relative+1": "måndag nästa vecka",
	"field-day-narrow-relative+-1": "i går",
	"field-year-short": "år",
	"field-day-narrow-relative+-2": "i förrgår",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-quarter-relative+-1": "förra kvartalet",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dayPeriods-standAlone-narrow-am": "fm",
	"field-week-narrow-relative+-1": "förra v.",
	"days-format-short": [
		"sö",
		"må",
		"ti",
		"on",
		"to",
		"fr",
		"lö"
	],
	"dayPeriods-format-wide-pm": "em",
	"field-sat-relative+-1": "lördag förra veckan",
	"dateFormatItem-Md": "d/M",
	"field-minute-narrow-relative+0": "denna minut",
	"field-hour": "timme",
	"months-format-wide": [
		"januari",
		"februari",
		"mars",
		"april",
		"maj",
		"juni",
		"juli",
		"augusti",
		"september",
		"oktober",
		"november",
		"december"
	],
	"dateFormat-full": "EEEE d MMMM y G",
	"field-month-relative+-1": "förra månaden",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "denna lör.",
	"field-fri-relative+0": "fredag denna vecka",
	"field-sat-narrow-relative+1": "nästa lör.",
	"field-fri-relative+1": "fredag nästa vecka",
	"field-month-narrow-relative+0": "denna mån.",
	"field-month-narrow-relative+1": "nästa mån.",
	"field-sun-short-relative+0": "sön. denna vecka",
	"field-sun-short-relative+1": "sön. nästa vecka",
	"field-week-relative+-1": "förra veckan",
	"field-quarter-short-relative+-1": "förra kv.",
	"field-minute-short-relative+0": "denna minut",
	"months-format-abbr": [
		"jan.",
		"feb.",
		"mars",
		"apr.",
		"maj",
		"juni",
		"juli",
		"aug.",
		"sep.",
		"okt.",
		"nov.",
		"dec."
	],
	"field-quarter-relative+0": "detta kvartal",
	"field-minute-relative+0": "denna minut",
	"timeFormat-long": "HH.mm.ss z",
	"field-quarter-relative+1": "nästa kvartal",
	"field-wed-short-relative+-1": "ons. förra veckan",
	"dateFormat-short": "G y-MM-dd",
	"field-thu-short-relative+-1": "tors. förra veckan",
	"field-year-narrow-relative+-1": "i fjol",
	"days-standAlone-wide": [
		"söndag",
		"måndag",
		"tisdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lördag"
	],
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"field-mon-narrow-relative+-1": "förra mån.",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "förra tors.",
	"field-tue-narrow-relative+-1": "förra tis.",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "em",
	"field-wed-short-relative+0": "ons. denna vecka",
	"months-standAlone-wide": [
		"januari",
		"februari",
		"mars",
		"april",
		"maj",
		"juni",
		"juli",
		"augusti",
		"september",
		"oktober",
		"november",
		"december"
	],
	"field-wed-short-relative+1": "ons. nästa vecka",
	"field-sun-relative+-1": "söndag förra veckan",
	"days-standAlone-abbr": [
		"sön",
		"mån",
		"tis",
		"ons",
		"tors",
		"fre",
		"lör"
	],
	"field-second-narrow-relative+0": "nu",
	"field-weekday": "veckodag",
	"field-day-short-relative+0": "i dag",
	"field-quarter-narrow-relative+0": "detta kv.",
	"field-sat-relative+0": "lördag denna vecka",
	"field-day-short-relative+1": "i morgon",
	"field-quarter-narrow-relative+1": "nästa kv.",
	"field-sat-relative+1": "lördag nästa vecka",
	"field-day-short-relative+2": "i övermorgon",
	"field-week-short-relative+0": "denna v.",
	"field-week-short-relative+1": "nästa v.",
	"months-standAlone-abbr": [
		"jan.",
		"feb.",
		"mars",
		"apr.",
		"maj",
		"juni",
		"juli",
		"aug.",
		"sep.",
		"okt.",
		"nov.",
		"dec."
	],
	"field-month-short-relative+0": "denna mån.",
	"field-month-short-relative+1": "nästa mån.",
	"timeFormat-full": "'kl'. HH.mm.ss zzzz",
	"dateFormatItem-MEd": "E d/M",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "denna tors.",
	"field-thu-narrow-relative+1": "nästa tors.",
	"field-sun-narrow-relative+-1": "förra sön.",
	"field-mon-short-relative+-1": "mån. förra veckan",
	"field-thu-relative+0": "torsdag denna vecka",
	"field-thu-relative+1": "torsdag nästa vecka",
	"field-fri-short-relative+-1": "fre. förra veckan",
	"field-thu-relative+-1": "torsdag förra veckan",
	"field-week": "vecka",
	"quarters-format-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "denna ons.",
	"field-wed-narrow-relative+1": "nästa ons.",
	"field-quarter-narrow-relative+-1": "förra kv.",
	"field-year-short-relative+0": "i år",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "nästa år",
	"field-fri-short-relative+0": "fre. denna vecka",
	"field-fri-short-relative+1": "fre. nästa vecka",
	"days-standAlone-short": [
		"sö",
		"må",
		"ti",
		"on",
		"to",
		"fr",
		"lö"
	],
	"field-week-short-relative+-1": "förra v.",
	"field-hour-narrow-relative+0": "denna timme",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "tim",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-month-narrow": "mån",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "förra fre.",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "nästa år",
	"field-fri-relative+-1": "fredag förra veckan",
	"field-tue-short-relative+-1": "tis. förra veckan",
	"field-minute-narrow": "m",
	"days-format-wide": [
		"söndag",
		"måndag",
		"tisdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lördag"
	],
	"field-mon-narrow-relative+0": "denna mån.",
	"field-mon-narrow-relative+1": "nästa mån.",
	"field-year-short-relative+-1": "i fjol",
	"field-zone": "tidszon",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "sön. förra veckan",
	"field-day-relative+-1": "i går",
	"dayPeriods-standAlone-abbr-am": "f.m.",
	"field-day-relative+-2": "i förrgår",
	"days-format-abbr": [
		"sön",
		"mån",
		"tis",
		"ons",
		"tors",
		"fre",
		"lör"
	],
	"field-sun-relative+0": "söndag denna vecka",
	"field-sun-relative+1": "söndag nästa vecka",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dag",
	"field-week-narrow": "v",
	"field-era": "era",
	"field-fri-narrow-relative+0": "denna fre.",
	"field-fri-narrow-relative+1": "nästa fre.",
	"dayPeriods-standAlone-wide-am": "förmiddag"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/sv/buddhist.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "detta kv.",
	"field-quarter-short-relative+1": "nästa kv.",
	"field-tue-relative+-1": "tisdag förra veckan",
	"field-year": "år",
	"field-wed-relative+0": "onsdag denna vecka",
	"field-wed-relative+1": "onsdag nästa vecka",
	"timeFormat-short": "HH.mm",
	"field-minute": "minut",
	"field-month-narrow-relative+-1": "förra mån.",
	"field-tue-narrow-relative+0": "denna tis.",
	"field-tue-narrow-relative+1": "nästa tis.",
	"field-thu-short-relative+0": "tors. denna vecka",
	"field-day-short-relative+-1": "i går",
	"dateTimeFormat-short": "{1} {0}",
	"field-thu-short-relative+1": "tors. nästa vecka",
	"field-day-relative+0": "i dag",
	"field-day-short-relative+-2": "i förrgår",
	"field-day-relative+1": "i morgon",
	"field-week-narrow-relative+0": "denna v.",
	"field-day-relative+2": "i övermorgon",
	"field-week-narrow-relative+1": "nästa v.",
	"field-wed-narrow-relative+-1": "förra ons.",
	"field-year-narrow": "år",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "i år",
	"field-tue-relative+0": "tisdag denna vecka",
	"field-year-narrow-relative+1": "nästa år",
	"field-tue-relative+1": "tisdag nästa vecka",
	"field-weekdayOfMonth": "veckodag i månad",
	"field-second-short": "sek",
	"dayPeriods-format-narrow-am": "fm",
	"dateFormatItem-yyyyMM": "y-MM G",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "veckodag i mån.",
	"dayPeriods-format-abbr-am": "fm",
	"field-week-relative+0": "denna vecka",
	"field-month-relative+0": "denna månad",
	"field-week-relative+1": "nästa vecka",
	"field-month-relative+1": "nästa månad",
	"field-sun-narrow-relative+0": "denna sön.",
	"timeFormat-medium": "HH.mm.ss",
	"field-mon-short-relative+0": "mån. denna vecka",
	"field-sun-narrow-relative+1": "nästa sön.",
	"field-mon-short-relative+1": "mån. nästa vecka",
	"field-second-relative+0": "nu",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"eraNames": [
		"Buddhistisk era"
	],
	"field-weekOfMonth": "vecka i månaden",
	"dayPeriods-standAlone-abbr-pm": "e.m.",
	"field-month-short": "m",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-yyyyMd": "y-MM-dd G",
	"field-day": "dag",
	"field-dayOfYear-short": "dag under året",
	"field-year-relative+-1": "i fjol",
	"dayPeriods-format-wide-am": "fm",
	"field-sat-short-relative+-1": "lör. förra veckan",
	"field-hour-relative+0": "denna timme",
	"dateFormatItem-yyyyMEd": "E y-MM-dd G",
	"field-second-short-relative+0": "nu",
	"field-wed-relative+-1": "onsdag förra veckan",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "förra lör.",
	"field-second": "sekund",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dayPeriods-standAlone-wide-pm": "eftermiddag",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-hour-short-relative+0": "denna timme",
	"field-quarter": "kvartal",
	"field-week-short": "v",
	"field-day-narrow-relative+0": "idag",
	"field-day-narrow-relative+1": "imorgon",
	"field-day-narrow-relative+2": "i övermorgon",
	"quarters-standAlone-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"field-tue-short-relative+0": "tis. denna vecka",
	"field-tue-short-relative+1": "tis. nästa vecka",
	"field-month-short-relative+-1": "förra mån.",
	"field-mon-relative+-1": "måndag förra veckan",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "månad",
	"field-day-narrow": "dag",
	"field-minute-short": "min",
	"field-dayperiod": "fm/em",
	"field-sat-short-relative+0": "lör. denna vecka",
	"field-sat-short-relative+1": "lör. nästa vecka",
	"dayPeriods-format-narrow-pm": "em",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"BE"
	],
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"dayPeriods-format-abbr-pm": "em",
	"dateFormatItem-yyyyM": "y-MM G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "måndag denna vecka",
	"field-mon-relative+1": "måndag nästa vecka",
	"field-day-narrow-relative+-1": "igår",
	"field-year-short": "år",
	"field-day-narrow-relative+-2": "i förrgår",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-quarter-relative+-1": "förra kvartalet",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "fm/em",
	"dayPeriods-standAlone-narrow-am": "fm",
	"field-week-narrow-relative+-1": "förra v.",
	"days-format-short": [
		"sö",
		"må",
		"ti",
		"on",
		"to",
		"fr",
		"lö"
	],
	"dayPeriods-format-wide-pm": "em",
	"field-dayOfYear": "dag under året",
	"field-sat-relative+-1": "lördag förra veckan",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d/M",
	"field-minute-narrow-relative+0": "denna minut",
	"field-hour": "timme",
	"months-format-wide": [
		"januari",
		"februari",
		"mars",
		"april",
		"maj",
		"juni",
		"juli",
		"augusti",
		"september",
		"oktober",
		"november",
		"december"
	],
	"dateFormat-full": "EEEE d MMMM y G",
	"field-month-relative+-1": "förra månaden",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "denna lör.",
	"field-fri-relative+0": "fredag denna vecka",
	"field-sat-narrow-relative+1": "nästa lör.",
	"field-fri-relative+1": "fredag nästa vecka",
	"field-month-narrow-relative+0": "denna mån.",
	"field-month-narrow-relative+1": "nästa mån.",
	"field-sun-short-relative+0": "sön. denna vecka",
	"field-sun-short-relative+1": "sön. nästa vecka",
	"field-week-relative+-1": "förra veckan",
	"field-quarter-short-relative+-1": "förra kv.",
	"field-minute-short-relative+0": "denna minut",
	"months-format-abbr": [
		"jan.",
		"feb.",
		"mars",
		"apr.",
		"maj",
		"juni",
		"juli",
		"aug.",
		"sep.",
		"okt.",
		"nov.",
		"dec."
	],
	"field-quarter-relative+0": "detta kvartal",
	"field-minute-relative+0": "denna minut",
	"timeFormat-long": "HH.mm.ss z",
	"field-quarter-relative+1": "nästa kvartal",
	"field-wed-short-relative+-1": "ons. förra veckan",
	"dateFormat-short": "y-MM-dd G",
	"field-thu-short-relative+-1": "tors. förra veckan",
	"field-year-narrow-relative+-1": "i fjol",
	"days-standAlone-wide": [
		"söndag",
		"måndag",
		"tisdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lördag"
	],
	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "förra tors.",
	"field-tue-narrow-relative+-1": "förra tis.",
	"field-weekOfMonth-short": "vk. i mån.",
	"dayPeriods-standAlone-narrow-pm": "em",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "ons. denna vecka",
	"months-standAlone-wide": [
		"januari",
		"februari",
		"mars",
		"april",
		"maj",
		"juni",
		"juli",
		"augusti",
		"september",
		"oktober",
		"november",
		"december"
	],
	"field-wed-short-relative+1": "ons. nästa vecka",
	"field-sun-relative+-1": "söndag förra veckan",
	"days-standAlone-abbr": [
		"sön",
		"mån",
		"tis",
		"ons",
		"tors",
		"fre",
		"lör"
	],
	"dateTimeFormat-full": "{1} {0}",
	"field-second-narrow-relative+0": "nu",
	"field-weekday": "veckodag",
	"field-day-short-relative+0": "i dag",
	"field-quarter-narrow-relative+0": "detta kv.",
	"field-day-short-relative+1": "i morgon",
	"field-sat-relative+0": "lördag denna vecka",
	"field-quarter-narrow-relative+1": "nästa kv.",
	"field-day-short-relative+2": "i övermorgon",
	"field-sat-relative+1": "lördag nästa vecka",
	"field-week-short-relative+0": "denna v.",
	"field-week-short-relative+1": "nästa v.",
	"months-standAlone-abbr": [
		"jan.",
		"feb.",
		"mars",
		"apr.",
		"maj",
		"juni",
		"juli",
		"aug.",
		"sep.",
		"okt.",
		"nov.",
		"dec."
	],
	"field-dayOfYear-narrow": "dag under året",
	"field-month-short-relative+0": "denna mån.",
	"field-month-short-relative+1": "nästa mån.",
	"field-weekdayOfMonth-short": "veckodag i mån.",
	"timeFormat-full": "'kl'. HH.mm.ss zzzz",
	"dateFormatItem-MEd": "E d/M",
	"field-zone-narrow": "tidszon",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "denna tors.",
	"field-thu-narrow-relative+1": "nästa tors.",
	"field-sun-narrow-relative+-1": "förra sön.",
	"field-mon-short-relative+-1": "mån. förra veckan",
	"field-thu-relative+0": "torsdag denna vecka",
	"field-thu-relative+1": "torsdag nästa vecka",
	"field-fri-short-relative+-1": "fre. förra veckan",
	"field-thu-relative+-1": "torsdag förra veckan",
	"field-week": "vecka",
	"quarters-format-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "denna ons.",
	"field-wed-narrow-relative+1": "nästa ons.",
	"field-quarter-narrow-relative+-1": "förra kv.",
	"field-year-short-relative+0": "i år",
	"field-dayperiod-short": "fm/em",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "nästa år",
	"field-fri-short-relative+0": "fre. denna vecka",
	"field-fri-short-relative+1": "fre. nästa vecka",
	"days-standAlone-short": [
		"sö",
		"må",
		"ti",
		"on",
		"to",
		"fr",
		"lö"
	],
	"field-week-short-relative+-1": "förra v.",
	"field-hour-narrow-relative+0": "denna timme",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "tim",
	"field-zone-short": "tidszon",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-month-narrow": "mån",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "förra fre.",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "nästa år",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "fredag förra veckan",
	"eraNarrow": "BE",
	"field-tue-short-relative+-1": "tis. förra veckan",
	"field-minute-narrow": "m",
	"days-format-wide": [
		"söndag",
		"måndag",
		"tisdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lördag"
	],
	"field-year-short-relative+-1": "i fjol",
	"field-zone": "tidszon",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-weekOfMonth-narrow": "vk.i mån.",
	"field-weekday-narrow": "veckodag",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "sön. förra veckan",
	"field-day-relative+-1": "i går",
	"dayPeriods-standAlone-abbr-am": "f.m.",
	"field-day-relative+-2": "i förrgår",
	"field-weekday-short": "veckodag",
	"days-format-abbr": [
		"sön",
		"mån",
		"tis",
		"ons",
		"tors",
		"fre",
		"lör"
	],
	"field-sun-relative+0": "söndag denna vecka",
	"dateFormatItem-MMdd": "d/M",
	"field-sun-relative+1": "söndag nästa vecka",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dag",
	"field-week-narrow": "v",
	"field-era": "era",
	"field-fri-narrow-relative+0": "denna fre.",
	"field-fri-narrow-relative+1": "nästa fre.",
	"dayPeriods-standAlone-wide-am": "förmiddag"
}
//end v1.x content
);
